@@ -3,7 +3,7 @@ import itertools
 
 import time
 from typing import Any, Iterable, Optional, Callable
-from aiohttp import ClientSession
+from aiohttp import ClientSession, TCPConnector, ClientTimeout
 from contextlib import asynccontextmanager
 from ..decorators.core import async_retry
 from .interface import RequestResult
@@ -70,16 +70,20 @@ class ConcurrentRequester:
             timeout: float | None = None,
     ):
         self._concurrency_limit = concurrency_limit
-        self._timeout = timeout
+        if timeout:
+            self._timeout = ClientTimeout(total=timeout, connect=min(10., timeout))
+        else:
+            self._timeout = None
         self._rate_limiter = RateLimiter(max_fps)
         self._semaphore = asyncio.Semaphore(concurrency_limit)
 
     @asynccontextmanager
     async def _get_session(self):
-        async with ClientSession() as session:
+        connector = TCPConnector(limit=self._concurrency_limit+10, limit_per_host=0, force_close=False)
+        async with ClientSession(timeout=self._timeout, connector=connector) as session:
             yield session
 
-    @async_retry(retry_times=3, retry_delay=1.0)
+    @async_retry(retry_times=3, retry_delay=0.55)
     async def _send_single_request(
             self,
             session: ClientSession,
@@ -98,7 +102,6 @@ class ConcurrentRequester:
 
                 async with session.request(
                         method, url,
-                        timeout=self._timeout,
                         **kwargs
                 ) as response:
                     data = await response.json()
